@@ -536,9 +536,9 @@ sub decodeJson {
     $bufr   = \$buf;
   }
 
-  require JSON::XS;
+  require JSON;
   my $jxs = $dc->{jxs};
-  $jxs    = $dc->{jxs} = JSON::XS->new->utf8(0)->relaxed(1)->canonical(0) if (!defined($jxs));
+  $jxs    = $dc->{jxs} = JSON->new->utf8(0)->relaxed(1)->canonical(0) if (!defined($jxs));
   return $jxs->decode($$bufr);
 }
 
@@ -568,7 +568,7 @@ __END__
 
 =head1 NAME
 
-DDC::Client - Client socket utilities for DDC
+DDC::Client - Client socket utilities for DDC::Concordance
 
 =head1 SYNOPSIS
 
@@ -621,7 +621,7 @@ DDC::Client - Client socket utilities for DDC
 
 =item Variable: $ifmt
 
-pack()-format to use for integer sizes passed to and from DDC.
+pack()-format to use for integer sizes passed to and from a DDC server.
 The default value ('V') should be right for ddc-2.x (always 32-bit unsigned little endian).
 For ddc-1.x, the machine word size and endian-ness should match the those native to the
 machine running the DDC server.
@@ -760,7 +760,7 @@ Reads fixed number of bytes from $fh (default=underlying socket).
  $data = $dc->readData();
  $data = $dc->readData($fh)
 
-Reads pending data from $fh (default=underlying socket); calls readSize() and readBytes().
+Reads pending data from $fh (default=underlying socket); calls L<readSize()|/readSize> and L<readBytes()|/readBytes>.
 
 =back
 
@@ -785,10 +785,10 @@ Reads pending data from $fh (default=underlying socket); calls readSize() and re
  \@hits = $dc->parseJsonData($buf);
 
 Parses raw DDC data buffer in $buf.
-Returns an array-ref of DDC::Hit objects representing
+Returns an array-ref of L<DDC::Hit|DDC::Hit> objects representing
 the individual hits.
 
-JSON parsing requires the JSON::XS module.
+JSON parsing requires the L<JSON|JSON> module.
 
 =back
 
@@ -809,10 +809,10 @@ Bryan Jurish E<lt>moocow@cpan.orgE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2006-2011 by Bryan Jurish
+Copyright (C) 2006-2016 by Bryan Jurish
 
 This package is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself, either Perl version 5.10.1 or,
+it under the same terms as Perl itself, either Perl version 5.14.2 or,
 at your option, any later version of Perl 5 you may have available.
 
 =cut
